/* ʣ̲ - EnbanKensa
 * Copyright (c) 2005 Kagetani Hideto
 * main.c - ᥤ
 * $Date: 2006/12/02 14:14:59 $
 * $Revision: 1.4 $
 */

#include <stdio.h>
#include <string.h>
#include <unistd.h>
#include <malloc.h>
#include <gtk/gtk.h>

#include "mainwindow.h"
#include "aspi.h"
#include <libintl.h>
#include "text.h"


int
main (int argc, char *argv[])
{
  GtkWidget *mainwindow;

  gtk_set_locale();
  bind_textdomain_codeset("EnbanKensa", "UTF-8");
  textdomain("EnbanKensa");
  gtk_init(&argc, &argv);

  gtk_window_set_default_icon_from_file("/usr/share/pixmaps/EnbanKensa.png", NULL);

  OpenAspi();

  mainwindow = create_mainwindow();
  gtk_widget_show(mainwindow);

  gtk_main ();

  CloseAspi();

  return 0;
}

